# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.swagger_client
from curia.api.swagger_client.api.internal_api import InternalApi  # noqa: E501
from curia.api.swagger_client.rest import ApiException


class TestInternalApi(unittest.TestCase):
    """InternalApi unit test stubs"""

    def setUp(self):
        self.api = InternalApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_code_controller_get_upload_url(self):
        """Test case for code_controller_get_upload_url

        """
        pass

    def test_create_many_base_code_controller_code(self):
        """Test case for create_many_base_code_controller_code

        Create many Code  # noqa: E501
        """
        pass

    def test_create_many_base_feature_category_controller_feature_category(self):
        """Test case for create_many_base_feature_category_controller_feature_category

        Create many FeatureCategory  # noqa: E501
        """
        pass

    def test_create_many_base_feature_controller_feature(self):
        """Test case for create_many_base_feature_controller_feature

        Create many Feature  # noqa: E501
        """
        pass

    def test_create_many_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for create_many_base_feature_sub_category_controller_feature_sub_category

        Create many FeatureSubCategory  # noqa: E501
        """
        pass

    def test_create_one_base_code_controller_code(self):
        """Test case for create_one_base_code_controller_code

        Create one Code  # noqa: E501
        """
        pass

    def test_create_one_base_feature_category_controller_feature_category(self):
        """Test case for create_one_base_feature_category_controller_feature_category

        Create one FeatureCategory  # noqa: E501
        """
        pass

    def test_create_one_base_feature_controller_feature(self):
        """Test case for create_one_base_feature_controller_feature

        Create one Feature  # noqa: E501
        """
        pass

    def test_create_one_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for create_one_base_feature_sub_category_controller_feature_sub_category

        Create one FeatureSubCategory  # noqa: E501
        """
        pass

    def test_delete_one_base_code_controller_code(self):
        """Test case for delete_one_base_code_controller_code

        Delete one Code  # noqa: E501
        """
        pass

    def test_delete_one_base_feature_category_controller_feature_category(self):
        """Test case for delete_one_base_feature_category_controller_feature_category

        Delete one FeatureCategory  # noqa: E501
        """
        pass

    def test_delete_one_base_feature_controller_feature(self):
        """Test case for delete_one_base_feature_controller_feature

        Delete one Feature  # noqa: E501
        """
        pass

    def test_delete_one_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for delete_one_base_feature_sub_category_controller_feature_sub_category

        Delete one FeatureSubCategory  # noqa: E501
        """
        pass

    def test_get_many_base_code_controller_code(self):
        """Test case for get_many_base_code_controller_code

        Retrieve many Code  # noqa: E501
        """
        pass

    def test_get_many_base_feature_category_controller_feature_category(self):
        """Test case for get_many_base_feature_category_controller_feature_category

        Retrieve many FeatureCategory  # noqa: E501
        """
        pass

    def test_get_many_base_feature_controller_feature(self):
        """Test case for get_many_base_feature_controller_feature

        Retrieve many Feature  # noqa: E501
        """
        pass

    def test_get_many_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for get_many_base_feature_sub_category_controller_feature_sub_category

        Retrieve many FeatureSubCategory  # noqa: E501
        """
        pass

    def test_get_one_base_code_controller_code(self):
        """Test case for get_one_base_code_controller_code

        Retrieve one Code  # noqa: E501
        """
        pass

    def test_get_one_base_feature_category_controller_feature_category(self):
        """Test case for get_one_base_feature_category_controller_feature_category

        Retrieve one FeatureCategory  # noqa: E501
        """
        pass

    def test_get_one_base_feature_controller_feature(self):
        """Test case for get_one_base_feature_controller_feature

        Retrieve one Feature  # noqa: E501
        """
        pass

    def test_get_one_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for get_one_base_feature_sub_category_controller_feature_sub_category

        Retrieve one FeatureSubCategory  # noqa: E501
        """
        pass

    def test_health_controller_health(self):
        """Test case for health_controller_health

        """
        pass

    def test_replace_one_base_code_controller_code(self):
        """Test case for replace_one_base_code_controller_code

        Replace one Code  # noqa: E501
        """
        pass

    def test_replace_one_base_feature_category_controller_feature_category(self):
        """Test case for replace_one_base_feature_category_controller_feature_category

        Replace one FeatureCategory  # noqa: E501
        """
        pass

    def test_replace_one_base_feature_controller_feature(self):
        """Test case for replace_one_base_feature_controller_feature

        Replace one Feature  # noqa: E501
        """
        pass

    def test_replace_one_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for replace_one_base_feature_sub_category_controller_feature_sub_category

        Replace one FeatureSubCategory  # noqa: E501
        """
        pass

    def test_sns_message_controller_handle_message(self):
        """Test case for sns_message_controller_handle_message

        """
        pass

    def test_sns_message_controller_handle_message_0(self):
        """Test case for sns_message_controller_handle_message_0

        """
        pass

    def test_update_one_base_code_controller_code(self):
        """Test case for update_one_base_code_controller_code

        Update one Code  # noqa: E501
        """
        pass

    def test_update_one_base_feature_category_controller_feature_category(self):
        """Test case for update_one_base_feature_category_controller_feature_category

        Update one FeatureCategory  # noqa: E501
        """
        pass

    def test_update_one_base_feature_controller_feature(self):
        """Test case for update_one_base_feature_controller_feature

        Update one Feature  # noqa: E501
        """
        pass

    def test_update_one_base_feature_sub_category_controller_feature_sub_category(self):
        """Test case for update_one_base_feature_sub_category_controller_feature_sub_category

        Update one FeatureSubCategory  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
